<?php
/**
 * @version    1.2.0
 * @package    RadioWave
 * @author     JoomlaWorks - https://www.joomlaworks.net
 * @copyright  Copyright (c) 2006 - 2020 JoomlaWorks Ltd. All rights reserved.
 * @license    https://www.joomlaworks.net/license
 */

use Joomla\CMS\Factory;
use Joomla\CMS\Language\Language;
use Joomla\CMS\Uri\Uri;

// No direct access
defined('_JEXEC') or die('Restricted access');

/* -------------------- Load additional Google Web Fonts per language [CAN EDIT] -------------------- */
/*
switch($language->getTag()){
    case 'el-GR';
        $document->addStyleSheet('//fonts.googleapis.com/css?family=X|Y|Z');
        break;
    case 'vi-VN';
        $document->addStyleSheet('//fonts.googleapis.com/css?family=X|Y|Z');
        break;
    case 'km-KH';
        $document->addStyleSheet('//fonts.googleapis.com/css?family=X|Y|Z');
        break;
}
*/

/* -------------------- Load Google Web Fonts [CAN EDIT] -------------------- */

$form = Factory::getApplication()->input;
$params = $form->get('params', '', 'ARRAY');
$defaultBodyFont = $params['nutpBodyFont'] ?? null;
$defaultHeaderFont = $form->get('nutpHeaderFont', '', 'STRING');
$jinput = JFactory::getApplication()->input;
$postData = $jinput->post->get('params', array(), 'ARRAY');
$this->params->set('params', $postData);
$this->params->loadArray($postData);
$bodyFont = $this->params->get('nutpBodyFont');
$headerFont = $this->params->get('nutpHeaderFont');

// --- Google Web Fonts ---
// Read fonts from cache. If cache file is not available download from CDN and create it.
$fontsData = json_decode(file_get_contents(Uri::getInstance()->toString('https://cdn.joomlaworks.org/gwf/gwf.php')));

// Build the URLs array
$fontFamilies = array();
foreach ($fontsData as $entry) {
    $url = htmlspecialchars_decode($entry->url);
    $info = parse_url($url);
    $vars = array();
    parse_str($info['query'], $vars);
    $fontFamilies[$entry->family] = $vars['family'];
}

$fonts = array();

if(isset($fontFamilies[$bodyFont])){
    $fonts[] = $fontFamilies[$bodyFont];
}
if(isset($fontFamilies[$headerFont])){
    $fonts[] = $fontFamilies[$headerFont];
}
if(count($fonts)){
    $fonts = array_filter($fonts);
    $fonts = array_unique($fonts);
}

$document = Factory::getDocument();
if (count($fonts)) {
    $googleWebFontsUrl = '//fonts.googleapis.com/css?family='.implode('|', $fonts).'&amp;subset=latin,latin-ext,cyrillic,cyrillic-ext,greek,greek-ext,khmer,vietnamese';
    $document->addStyleSheet($googleWebFontsUrl);
}

// Apply font styles inline to override any other CSS rules
if ($bodyFont && $bodyFont != $defaultBodyFont && $bodyFont != "") {
    $document->addStyleDeclaration("body, input, textarea, input[type='text'], .sans, .k2ReportCommentFormContainer form label { font-family : '".$bodyFont."'}");
}

// Apply font styles inline to override any other CSS rules
if ($headerFont && $headerFont != $defaultHeaderFont) {
    $document->addStyleDeclaration(".itemFullText blockquote p { font-family : '".$headerFont."'}");
    $document->addStyleDeclaration("::-webkit-input-placeholder, ::-moz-placeholder, input:-moz-placeholder { font-family : '".$headerFont."'}");
}

/* -------------------- Content Highlights [CAN EDIT] -------------------- */
if ($this->params->get('contentHighlights')) {
    $highlights = $this->params->get('contentHighlights');

    // Set the icon font
    if ($highlights->font) {
        $font = $highlights->font;
        $document->addScriptDeclaration('
            WebFontConfig = {
                custom: {
                    families: [\''.$font.'\'],
                    urls: [\'https://cdn.joomlaworks.org/webfonts/'.$font.'/css/fontello.css\']
                }
            };
            (function() {
                var wf = document.createElement(\'script\');
                wf.src = (\'https:\' == document.location.protocol ? \'https\' : \'http\') + \'://ajax.googleapis.com/ajax/libs/webfont/1/webfont.js\';
                wf.type = \'text/javascript\';
                wf.async = \'true\';
                var s = document.getElementsByTagName(\'script\')[0];
                s.parentNode.insertBefore(wf, s);
            })();
        ');
        $document->addCustomTag('
            <!--[if IE 7]>
            <link rel="stylesheet" href="https://cdn.joomlaworks.org/webfonts/'.$font.'/css/fontello-ie7.css">
            <![endif]-->
        ');
    }

    // Set the rest of the output
    if (is_array($highlights)) {
        foreach ($highlights as $highlight) {
            // Do something with each highlight object/array returned
        }
    } else {
        // We probably have 1 highlight set so let's loop through its object/array
    }
}

/* -------------------- Content Variations [CAN EDIT] -------------------- */
if ($this->params->get('contentVariations', 'default')) {
    // Do something with the specific content (site) variation
}
/* -------------------- Color Variations [CAN EDIT] -------------------- */
if ($this->params->get('colorVariations', 'default') && $this->params->get('colorVariations')!='default') {
    if ($nuBodyClass) {
        $nuBodyClass .= ' themeIs'.$this->params->get('colorVariations');
    }
    ob_start();
    include(JPATH_SITE.'/templates/'.$this->template.'/css/colorvariations.css');
    $colorVariations = ob_get_clean();

    if (strpos($this->params->get('colorVariations'), '|')!==false && $this->params->get('colorVariations')!='custom') {
        $colors = explode('|', $this->params->get('colorVariations'));
        foreach ($colors as $key=>$color) {
            if ($key==0) {
                $colorVariations = str_replace('_IMAGEFOLDER_', $color, $colorVariations);
            } else {
                $colorsInRGB = hex2rgb($color);
                $colorVariations = str_replace('_COLOR'.$key.'_RGB_', $colorsInRGB, $colorVariations);
                $colorVariations = str_replace('_COLOR'.$key.'_', $color, $colorVariations);
            }
        }
    } else {
        $colorsInRGB_1 =  hex2rgb($this->params->get('_COLOR1_'));
        $colorsInRGB_2 =  hex2rgb($this->params->get('_COLOR2_'));
        $colorsInRGB_3 =  hex2rgb($this->params->get('_COLOR3_'));
        $colorsInRGB_4 =  hex2rgb($this->params->get('_COLOR4_'));
        $colorVariations = str_replace('_IMAGEFOLDER_', 'default', $colorVariations);
        $colorVariations = str_replace('_COLOR1_RGB_', $colorsInRGB_1, $colorVariations);
        $colorVariations = str_replace('_COLOR1_', $this->params->get('_COLOR1_'), $colorVariations);
        $colorVariations = str_replace('_COLOR2_RGB_', $colorsInRGB_2, $colorVariations);
        $colorVariations = str_replace('_COLOR2_', $this->params->get('_COLOR2_'), $colorVariations);
        $colorVariations = str_replace('_COLOR3_RGB_', $colorsInRGB_3, $colorVariations);
        $colorVariations = str_replace('_COLOR3_', $this->params->get('_COLOR3_'), $colorVariations);
        $colorVariations = str_replace('_COLOR4_RGB_', $colorsInRGB_4, $colorVariations);
        $colorVariations = str_replace('_COLOR4_', $this->params->get('_COLOR4_'), $colorVariations);
    }
    if (strlen($colorVariations)>10) {
        $colorVariations = str_replace('_TEMPLATEPATH_', $templatePath, $colorVariations);
        $document->addStyleDeclaration($colorVariations);
    }
}

/* -------------------- Category Colors [CAN EDIT] -------------------- */
if ($this->params->get('categoryColors')) {
    $categoryColors = $this->params->get('categoryColors');
    if (is_array($categoryColors)) {
        foreach ($categoryColors as $categoryColor) {
            // Do something with each category color array returned
            // Type: $categoryColor['type'], 'joomla' or 'k2'
            // Category: $categoryColor['category'], The id of the category
            // Color: $categoryColor['category'], The color value
        }
    }
}

/* -------------------- Sub-templates [CAN EDIT] -------------------- */
/* component.php */
if ($tmpl=='component') {
    // do stuff here for the component sub-template
}

/* raw.php */
if ($tmpl=='raw') {
    // do stuff here for the raw sub-template
}

$active = $menu->getActive();
if ($active) {
    $pageHeading = $active->params->get('page_heading');
    $pageBgImage = $active->params->get('menu_image');
    $pageSuffix = $active->params->get('pageclass_sfx');
}

// Our bottom module container class
if ($this->countModules('RadioWave_Bottom')%4==0) {
    $rowclass=' oneFourth';
} elseif ($this->countModules('RadioWave_Bottom')%3==0) {
    $rowclass=' oneThird';
} elseif ($this->countModules('RadioWave_Bottom')%2==0) {
    $rowclass=' half';
} elseif ($this->countModules('RadioWave_Bottom')==1) {
    $rowclass=' fullWidth';
} else {
    $rowclass=' oneFourth';
}

/* -------------------- Custom Template Logic [CAN EDIT] -------------------- */
// Extend the <body> class
if ($nuBodyClass) {
    $nuBodyClass .= '';
}
if (isset($pageSuffix)) {
    $nuBodyClass .= " ".$pageSuffix;
}

if ($this->params->get('nutpBgImage')) {
    $bgImg = $this->params->get('nutpBgImage');
    $bgImgVar= 'style="background-image:url('.$bgImg.')";';
} else {
    $bgImgVar="";
}
